==> igniteui-react-18.5.1.tgz: package/esm2015/lib/igr-circular-progress.js <==
import * as React from 'react';
import { IgrProgressBase } from "./igr-progress-base";
import { CircularProgress } from "./CircularProgress";
import { IgcCircularProgressComponent, defineComponents } from "igniteui-webcomponents";
/**
 * A circular progress indicator used to express unspecified wait time or display
 * the length of a process.
*/
export class IgrCircularProgress extends IgrProgressBase {
    createImplementation() {
        return new CircularProgress();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcCircularProgressComponent);
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-circular-progress", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
}

==> igniteui-react-18.6.0.tgz: package/esm2015/lib/igr-circular-progress.js <==
import * as React from 'react';
import { IgrProgressBase } from "./igr-progress-base";
import { CircularProgress } from "./CircularProgress";
import { IgcCircularProgressComponent, defineComponents } from "igniteui-webcomponents";
/**
 * A circular progress indicator used to express unspecified wait time or display
 * the length of a process.
*/
export class IgrCircularProgress extends IgrProgressBase {
    createImplementation() {
        return new CircularProgress();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcCircularProgressComponent);
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-circular-progress", {
            ref: this._getMainRef,
            id: this.props.id,
            class: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
}
